@@ -1,4 +1,4 @@
-# $Id: /mirror/perl/Catalyst-Plugin-Apoptosis/trunk/lib/Catalyst/Plugin/Apoptosis/GTop.pm 2551 2007-09-17T15:56:49.702151Z daisuke  $
+# $Id: /mirror/perl/Catalyst-Plugin-Apoptosis/trunk/lib/Catalyst/Plugin/Apoptosis/GTop.pm 2552 2007-09-18T08:36:57.555445Z daisuke  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
@@ -7,6 +7,14 @@ package Catalyst::Plugin::Apoptosis::GTop;
 use strict;
 use base qw(Catalyst::Plugin::Apoptosis Class::Data::Inheritable);
 use GTop;
+BEGIN
+{
+    if (my $code = GTop->can('THREADED')) {
+        if (! $code->()) {
+            delete $INC{'threads.pm'};
+        }
+    }
+}
 
 __PACKAGE__->mk_classdata($_) for qw(gtop);
 
